@@ -5,7 +5,8 @@ OPENPACK_ACC_DATASET_CONFIG = DatasetConfig(
     streams=None,
     stream=datasets.streams.ATR_ACC_STREAM,
     split=datasets.splits.PILOT_CHALLENGE_SPLIT,
-    annotation=datasets.annotations.OPENPACK_OPERATIONS_ANNOTATION,
+    annotation=datasets.annotations.ACTIVITY_1S_ANNOTATION,
+    classes=datasets.annotations.OPENPACK_OPERATIONS,
 )
 
 OPENPACK_2D_KEYPOINT_DATASET_CONFIG = DatasetConfig(
@@ -13,5 +14,6 @@ OPENPACK_2D_KEYPOINT_DATASET_CONFIG = DatasetConfig(
     streams=None,
     stream=datasets.streams.KINECT_2D_KPT_STREAM,
     split=datasets.splits.PILOT_CHALLENGE_SPLIT,
-    annotation=datasets.annotations.OPENPACK_OPERATIONS_ANNOTATION,
+    annotation=datasets.annotations.ACTIVITY_1S_ANNOTATION,
+    classes=datasets.annotations.OPENPACK_OPERATIONS,
 )
